#[non_exhaustive]pub enum ChannelError {
Implementation(Box<dyn Error + Sync + Send>),
ReportDescriptor(ParserError),
HidppNotSupported,
MessageTypeNotSupported,
NoResponse,
}Expand description
Represents an error that occurred when creating or interacting with a HID or HID++ communication channel.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementation(Box<dyn Error + Sync + Send>)
Indicates that the concrete implementation of RawHidChannel returned
an error.
ReportDescriptor(ParserError)
Indicates that the HID report descriptor could not be parsed.
HidppNotSupported
Indicates that the channel in question does not support HID++.
MessageTypeNotSupported
Indicates that the HID++ channel does not support messages of the given type (short/long).
NoResponse
Indicates that no response was received following a request.