#[non_exhaustive]pub enum DeviceError {
Channel(ChannelError),
DeviceNotFound,
UnsupportedProtocolVersion,
}Expand description
Represents a device-specific error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Channel(ChannelError)
Indicates that the underlying HidppChannel returned an error.
DeviceNotFound
Indicates that the specified device index points to no device.
UnsupportedProtocolVersion
Indicates that the addressed device does only support HID++1.0.