Module feature

Module feature 

Specific device feature implementations.

Modules

device_friendly_name
Implements the DeviceFriendlyName feature (ID 0x0007) that provides functionality to set and retrieve a custom device name.
device_information
Implements the DeviceInformation feature (ID 0x0003) that provides some general information about the device.
device_type_and_name
Implements the DeviceTypeAndName feature (ID 0x0005) that provides some information about the marketing type and name of a device.
feature_set
Implements the FeatureSet feature (ID 0x0001) that allows enumerating all the features supported by a device.
hires_wheel
Implements the HiResWheel feature (ID 0x2121) that allows configuring and using high-resolution scrolling.
registry
Maintains a registry of well-known HID++2.0 features and their default implementations.
root
Implements the Root feature (ID 0x0000) that every device supports by default.
smartshift
Implements the SmartShift feature (ID 0x2110) that allows controlling a smart shift enhanced scroll wheel.
thumbwheel
Implements the Thumbwheel feature (ID 0x2150) that allows configuration and diversion of thumbwheel events.
unified_battery
Implements the UnifiedBattery feature (ID 0x1004) that provides information about the battery status of the device.
wireless_device_status
Implements the WirelessDeviceStatus feature (ID 0x1d4b) that notifies the host about device reconnections.

Structs

FeatureType
A bitfield describing some properties of a feature.

Traits

CreatableFeature
Represents a Feature that can be instantiated automatically.
EmittingFeature
Represents a Feature that emits events of type T.
Feature
Represents a concrete implementation of a HID++2.0 device feature.