#[non_exhaustive]pub struct BacklightConfig {
pub enabled: bool,
pub options: BacklightOptions,
pub mode: BacklightMode,
pub effect_list: BacklightEffectList,
pub current_level: u8,
pub duration_hands_out: u16,
pub duration_hands_in: u16,
pub duration_powered: u16,
}Expand description
The backlight configuration from BacklightFeature::get_backlight_config.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolWhether the backlight system is enabled.
options: BacklightOptionsEnabled options and supported capabilities.
mode: BacklightModeCurrently selected backlight mode.
effect_list: BacklightEffectListEffects the device supports.
current_level: u8Current manual brightness level (0 = off, up to 7).
duration_hands_out: u16Fade-out duration after the last keystroke with no proximity, in 5-second
units (1..=0x05a0).
duration_hands_in: u16Fade-out duration while hands remain in the detection zone, in 5-second units.
duration_powered: u16Fade-out duration while externally powered, in 5-second units.