pub struct DeviceInformationFeature { /* private fields */ }Expand description
Implements the DeviceInformation / 0x0003 feature.
Implementations
Sourceimpl DeviceInformationFeature
impl DeviceInformationFeature
Sourcepub async fn get_device_info(&self) -> Result<DeviceInformation, Hidpp20Error>
pub async fn get_device_info(&self) -> Result<DeviceInformation, Hidpp20Error>
Retrieves general information about the device and its capabilities.
Sourcepub async fn get_fw_info(
&self,
entity_index: u8,
) -> Result<DeviceEntityFirmwareInfo, Hidpp20Error>
pub async fn get_fw_info( &self, entity_index: u8, ) -> Result<DeviceEntityFirmwareInfo, Hidpp20Error>
Retrieves information about the firmware of a specific entity,
identified by its index bound by the value in
DeviceInformation::entity_count.
Sourcepub async fn get_serial_number(&self) -> Result<String, Hidpp20Error>
pub async fn get_serial_number(&self) -> Result<String, Hidpp20Error>
Retrieves the serial number of the device.
This function was added in feature version 4 and will likely result in
an v20::ErrorType::InvalidFunctionId error for older versions,
so DeviceInformationCapabilities::serial_number should be
verified before calling.