#[non_exhaustive]pub struct DeviceTransport {
pub usb: bool,
pub e_quad: bool,
pub btle: bool,
pub bluetooth: bool,
}Expand description
Represents the bitfield stating which transport protocols a device supports.
One given device can only support up to three transport protocols at a time.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.usb: boolWhether the device supports USB.
e_quad: boolWhether the device supports eQuad, the protocol used by the Unifying Receiver.
btle: boolWhether the device supports Bluetooth Low Energy as used by the Bolt Receiver.
bluetooth: boolWhether the device supports Bluetooth.