#[non_exhaustive]#[repr(u8)]pub enum DualPlatformSelection {
IosOrMac = 0,
AndroidOrWindows = 1,
}Expand description
The platform a DualPlatformFeature device is configured for.
The selection is persistent and chosen by the user during pairing or by short pressing an OS-selection button; there is no default.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.