pub struct FnInversionWithDefaultStateFeature { /* private fields */ }Expand description
Implements FnInversionWithDefaultState / 0x40a2.
This is the single-host predecessor of
FnInversionMultiHostFeature (0x40a3): the inversion state is global
rather than per host slot.
Implementations
Sourceimpl FnInversionWithDefaultStateFeature
impl FnInversionWithDefaultStateFeature
Sourcepub async fn get_global_fn_inversion(
&self,
) -> Result<GlobalFnInversion, Hidpp20Error>
pub async fn get_global_fn_inversion( &self, ) -> Result<GlobalFnInversion, Hidpp20Error>
Retrieves the global Fn inversion state and its default.
Sourcepub async fn set_global_fn_inversion(
&self,
state: FnInversionState,
) -> Result<GlobalFnInversion, Hidpp20Error>
pub async fn set_global_fn_inversion( &self, state: FnInversionState, ) -> Result<GlobalFnInversion, Hidpp20Error>
Sets the global Fn inversion state and returns the resulting state.