#[non_exhaustive]pub struct MousePointerInfo {
pub sensor_resolution: u16,
pub pointer_acceleration: PointerAcceleration,
pub suggest_os_ballistics: bool,
pub suggest_vertical_tuning: bool,
}Expand description
Mouse-pointer information returned by
MousePointerFeature::get_mouse_pointer_info.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sensor_resolution: u16Typical sensor resolution on a standard surface, in 1-DPI steps.
Real-world resolution may differ from this value by up to ±20% depending on the surface.
pointer_acceleration: PointerAccelerationThe acceleration curve the device suggests.
suggest_os_ballistics: boolWhether the device suggests using the OS-native ballistics.
false means the host may override the OS ballistics if it can; true
means the device suggests keeping the OS-native ballistics.
suggest_vertical_tuning: boolWhether the device suggests offering vertical-orientation tuning.
true for devices such as trackballs, where the host can let the user
fine-tune X/Y movement relative to cursor movement.