pub struct PersistentRemappableActionFeature { /* private fields */ }Expand description
Implements the PersistentRemappableAction / 0x1c00 feature.
Implementations
Sourceimpl PersistentRemappableActionFeature
impl PersistentRemappableActionFeature
Sourcepub async fn get_feature_info(
&self,
) -> Result<RemappableCapabilities, Hidpp20Error>
pub async fn get_feature_info( &self, ) -> Result<RemappableCapabilities, Hidpp20Error>
Retrieves which HID outputs the device’s remapping can produce.
Sourcepub async fn get_count(&self) -> Result<RemappableInfo, Hidpp20Error>
pub async fn get_count(&self) -> Result<RemappableInfo, Hidpp20Error>
Retrieves the control-ID count and host count.
Sourcepub async fn get_cid_info(
&self,
index: u8,
host: HostIndex,
) -> Result<ControlId, Hidpp20Error>
pub async fn get_cid_info( &self, index: u8, host: HostIndex, ) -> Result<ControlId, Hidpp20Error>
Retrieves the control ID at table index for host.
Sourcepub async fn get_persistent_action(
&self,
cid: ControlId,
host: HostIndex,
) -> Result<PersistentAction, Hidpp20Error>
pub async fn get_persistent_action( &self, cid: ControlId, host: HostIndex, ) -> Result<PersistentAction, Hidpp20Error>
Retrieves the persistent action mapped to cid on host.
Sourcepub async fn set_persistent_action(
&self,
cid: ControlId,
host: HostIndex,
config: PersistentActionConfig,
) -> Result<(), Hidpp20Error>
pub async fn set_persistent_action( &self, cid: ControlId, host: HostIndex, config: PersistentActionConfig, ) -> Result<(), Hidpp20Error>
Persistently remaps cid on host to config.
This writes to the device’s non-volatile memory and changes the control’s
behaviour until reset (see Self::reset_persistent_action).
Sourcepub async fn reset_persistent_action(
&self,
cid: ControlId,
host: HostIndex,
) -> Result<(), Hidpp20Error>
pub async fn reset_persistent_action( &self, cid: ControlId, host: HostIndex, ) -> Result<(), Hidpp20Error>
Resets cid on host to its factory default action.
Sourcepub async fn reset_to_factory_settings(
&self,
hosts: HostMask,
) -> Result<(), Hidpp20Error>
pub async fn reset_to_factory_settings( &self, hosts: HostMask, ) -> Result<(), Hidpp20Error>
Resets every control to its factory default for the hosts in hosts.