pub struct FeatureVersion {
pub starting_version: u8,
pub producer: FeatureImplProducer,
}Expand description
Represents a known feature implementation starting from a specific feature version.
Fields
starting_version: u8The minimum feature version the implementation supports.
producer: FeatureImplProducerA pointer to a function producing the feature implementation.