pub struct KnownFeature {
pub name: &'static str,
pub versions: &'static [FeatureVersion],
}Expand description
Represents a known HID++2.0 device feature.
Fields
name: &'static strThe name of the feature. This is usually a slightly modified version of the name found in Logitech’s documentation.
versions: &'static [FeatureVersion]A list of concrete implementations of the feature, each supporting the feature starting from a specific version.