#[non_exhaustive]pub struct FeatureInformation {
pub index: u8,
pub typ: FeatureType,
pub version: u8,
}Expand description
Represents information about a specific feature as returned by the
RootFeature::get_feature function.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index: u8The index of the feature in the version table. This is used for invocations of functions of that feature.
typ: FeatureTypeThe type of the feature.
version: u8The latest supported version of the feature.
Multi-version features are always backwards compatible as long as the feature ID does not change, meaning functions implemented for an older version of the same feature will behave as expected for every later version.
This field was added in feature version 1 and will be 0 for all older
versions.