Module smartshift

Module smartshift 

Implements the SmartShift feature (ID 0x2110) that allows controlling a smart shift enhanced scroll wheel.

Structs

RatchetControlMode
Represents the ratchet control mode of the mouse wheel.
SmartShiftFeature
Implements the SmartShift / 0x2110 feature.

Enums

WheelMode
Represents the ratchet mode of the scroll wheel.