#[non_exhaustive]#[repr(u8)]pub enum ErrorType {
Show 13 variants
Success = 0,
InvalidSubId = 1,
InvalidAddress = 2,
InvalidValue = 3,
ConnectFail = 4,
TooManyDevices = 5,
AlreadyExists = 6,
Busy = 7,
UnknownDevice = 8,
ResourceError = 9,
RequestUnavailable = 10,
InvalidParamValue = 11,
WrongPinCode = 12,
}Expand description
Represents the type of an error a HID++1.0 device returns as part of a
message with the MessageType::Error type.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Success = 0
No error.
InvalidSubId = 1
The sub ID of a sent message is invalid.
InvalidAddress = 2
The address included in a sent message is invalid.
InvalidValue = 3
The value included in a sent message is invalid.
ConnectFail = 4
A connection request failed on the receiver’s side.
TooManyDevices = 5
The receiver indicates that too many devices are connected to it.
AlreadyExists = 6
The reciever indicates that something already exists. This error is not further documented, please let me know what it means.
Busy = 7
The receiver is currently handling a downstream (to device) message and cannot process a second one.
UnknownDevice = 8
Trying to send a message to a device (device index) where there is no device paired.
ResourceError = 9
This error is returned by the receiver when a HID++ command has been sent to a device that is in disconnected mode. When a device is in disconnected mode it cannot receive commands from the host until it reconnects. A device reconnects when the user interacts with it. In most cases, a device disconnects after several minutes of inactivity.
A sent request is not available in the current context.
InvalidParamValue = 11
A request parameter has an unsupported value.
WrongPinCode = 12
The PIN code of a device was wrong.