#[non_exhaustive]pub enum Hidpp10Error {
Channel(ChannelError),
RegisterAccess(ErrorType),
UnsupportedResponse,
}Expand description
Represents an error that may occur when accessing registers using HID++1.0.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Channel(ChannelError)
Indicates that an error occurred while communicating across the HID++ channel.
RegisterAccess(ErrorType)
Indicates that a register access failed.
UnsupportedResponse
Indicates that a received response is not fully supported.