#[non_exhaustive]#[repr(u8)]pub enum MessageType {
SetRegister = 128,
GetRegister = 129,
SetLongRegister = 130,
GetLongRegister = 131,
Error = 143,
}Expand description
Represents a globally defined sub ID of a HID++1.0 message.
This enum only includes sub IDs that are defined globally across all devices. Most devices (e.g. the Unifying Receiver) define additional sub IDs specific to their functionality.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
SetRegister = 128
Used to set a 3-byte register value. A sent message of this type is
usually responded with a response message of the same type (or
Self::Error).
GetRegister = 129
Used to retrieve a 3-byte register value. A sent message of this type is
usually responded with a response message of the same type (or
Self::Error).
SetLongRegister = 130
Used to set a 16-byte register value. A sent message of this type is
usually responded with a response message of the same type (or
Self::Error).
GetLongRegister = 131
Used to retrieve a 16-byte register value. A sent message of this type
is usually responded with a response message of the same type (or
Self::Error).
Error = 143
Used to indicate an error response. The error code usually included in
the message can be mapped using ErrorType::try_from.