#[non_exhaustive]pub enum Hidpp20Error {
Channel(ChannelError),
Feature(ErrorType),
UnsupportedResponse,
}Expand description
Represents an error that may occur when calling a HID++2.0 feature function.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Channel(ChannelError)
Indicates that an error occurred while communicating across the HID++ channel.
Feature(ErrorType)
Indicates that a call to a HID++2.0 feature function resulted in an error.
UnsupportedResponse
Indicates that a received response is not fully supported.