pub enum Message {
Short(MessageHeader, [u8; 3]),
Long(MessageHeader, [u8; 16]),
}Expand description
Represents a HID++2.0 message.
Variants
Short(MessageHeader, [u8; 3])
Represents a short HID++2.0 message with 3 bytes of payload.
Long(MessageHeader, [u8; 16])
Represents a long HID++2.0 message with 16 bytes of payload.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn header(&self) -> MessageHeader
pub fn header(&self) -> MessageHeader
Extracts the header of the message.
Sourcepub fn extend_payload(&self) -> [u8; 16]
pub fn extend_payload(&self) -> [u8; 16]
Extracts the payload of the message and fits it into an array capable of containing the longest possible payload, filling the rest up with zeroes.