#[non_exhaustive]#[repr(u8)]pub enum Register {
Notifications = 0,
Connections = 2,
ReceiverInfo = 181,
DeviceDiscovery = 192,
Pairing = 193,
UniqueId = 251,
}Expand description
All known registers of the Bolt receiver.
In most cases you should not need to access these manually, as Receiver
implements many features.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Notifications = 0
Allows control over what notifications the receiver sends.
Connections = 2
Provides the amount of currently paired devices.
This is exposed by Receiver::count_pairings.
ReceiverInfo = 181
Provides information about the receiver and paired devices.
It uses sub-registers, as defined in InfoSubRegister, to
differentiate between different kinds of information.
DeviceDiscovery = 192
Provides support for discovering devices that are ready to pair.
Use Receiver::discover_devices and
Receiver::cancel_device_discovery to control device discovery.
Pairing = 193
Provides pairing and unpairing support.
Use Receiver::pair_device and Receiver::unpair_device for
pairing and unpairing.
UniqueId = 251
Exposes the unique ID of the receiver. This seems to differ from the serial number.
Use Receiver::get_unique_id to query this value.