Receiver

Enum Receiver 

#[non_exhaustive]
pub enum Receiver { Bolt(Receiver), Unifying(Receiver), }
Represents a HID++ wireless receiver.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Bolt(Receiver)



Unifying(Receiver)

Implementations

Source

impl Receiver

pub fn name(&self) -> String

Provides a human-readable name for the receiver.

pub async fn get_unique_id(&self) -> Result<String, ReceiverError>

Provides a string that uniquely identifies the specific receiver.

This MAY be the serial number, but it may also be any other value that is defined as unique.