pub struct Receiver { /* private fields */ }Expand description
Implements the Unifying wireless receiver.
Implementations
Sourceimpl Receiver
impl Receiver
Sourcepub fn new(chan: Arc<HidppChannel>) -> Result<Self, ReceiverError>
pub fn new(chan: Arc<HidppChannel>) -> Result<Self, ReceiverError>
Tries to initialize a new [UnifyingReceiver] from a raw HID++ channel.
If no receiver could be found, or if the vendor and product IDs don’t
match the ones of any known Unifying receiver, this function will return
ReceiverError::UnknownReceiver.
Sourcepub async fn get_receiver_info(&self) -> Result<ReceiverInfo, ReceiverError>
pub async fn get_receiver_info(&self) -> Result<ReceiverInfo, ReceiverError>
Provides general information about the receiver.