Specific device feature implementations.
Modules
- device_
friendly_ name - Implements the
DeviceFriendlyNamefeature (ID0x0007) that provides functionality to set and retrieve a custom device name. - device_
information - Implements the
DeviceInformationfeature (ID0x0003) that provides some general information about the device. - device_
type_ and_ name - Implements the
DeviceTypeAndNamefeature (ID0x0005) that provides some information about the marketing type and name of a device. - feature_
set - Implements the
FeatureSetfeature (ID0x0001) that allows enumerating all the features supported by a device. - hires_
wheel - Implements the
HiResWheelfeature (ID0x2121) that allows configuring and using high-resolution scrolling. - registry
- Maintains a registry of well-known HID++2.0 features and their default implementations.
- root
- Implements the
Rootfeature (ID0x0000) that every device supports by default. - smartshift
- Implements the
SmartShiftfeature (ID0x2110) that allows controlling a smart shift enhanced scroll wheel. - thumbwheel
- Implements the
Thumbwheelfeature (ID0x2150) that allows configuration and diversion of thumbwheel events. - unified_
battery - Implements the
UnifiedBatteryfeature (ID0x1004) that provides information about the battery status of the device. - wireless_
device_ status - Implements the
WirelessDeviceStatusfeature (ID0x1d4b) that notifies the host about device reconnections.
Structs
- Feature
Type - A bitfield describing some properties of a feature.
Traits
- Creatable
Feature - Represents a
Featurethat can be instantiated automatically. - Emitting
Feature - Represents a
Featurethat emits events of typeT. - Feature
- Represents a concrete implementation of a HID++2.0 device feature.