Module feature

Module feature 

Specific device feature implementations.

Modules

adjustable_dpi
Implements the AdjustableDpi feature (ID 0x2201) that allows reading and changing a mouse sensor’s DPI.
backlight
Implements the Backlight feature (ID 0x1982, version 3) for keyboards with an adjustable backlight.
brightness_control
Implements BrightnessControl (feature 0x8040).
change_host
Implements the ChangeHost feature (ID 0x1814) that selects which host / RF channel a multi-host device is connected to.
color_led_effects
Implements the ColorLedEffects feature (ID 0x8070, version 7), the per-zone RGB effect engine used by Logitech keyboards and mice.
crown
Implements the Crown feature (ID 0x4600) for the MX Master’s rotary crown: reading its capabilities, configuring its mode (HID vs diverted, free vs ratchet, timeouts), and receiving diverted rotation/touch/button events.
device_friendly_name
Implements the DeviceFriendlyName feature (ID 0x0007) that provides functionality to set and retrieve a custom device name.
device_information
Implements the DeviceInformation feature (ID 0x0003) that provides some general information about the device.
device_type_and_name
Implements the DeviceTypeAndName feature (ID 0x0005) that provides some information about the marketing type and name of a device.
disable_keys
Implements the DisableKeys feature (ID 0x4521) that disables a fixed set of lock / system keys.
disable_keys_by_usage
Implements the DisableKeysByUsage feature (ID 0x4522) that disables or enables arbitrary keyboard keys by HID usage.
dual_platform
Implements the DualPlatform feature (ID 0x4530) that selects which of two OS platforms a device sends HID codes for.
equalizer
Implements the Equalizer feature (ID 0x8310, version 2) that configures an audio device’s equalizer (per-band gains) and microphone noise reduction.
extended_dpi
Implements the ExtendedAdjustableDpi feature (ID 0x2202).
extended_report_rate
Implements ExtendedAdjustableReportRate (feature 0x8061).
feature_set
Implements the FeatureSet feature (ID 0x0001) that allows enumerating all the features supported by a device.
fn_inversion
Implements function-key inversion features.
hires_wheel
Implements the HiResWheel feature (ID 0x2121) that allows configuring and using high-resolution scrolling.
hosts_info
Implements HostsInfo (feature 0x1815) for multi-host devices.
illumination
Implements the Illumination feature (ID 0x1990) for devices with a controllable illumination light (brightness in Lumens and color temperature in Kelvin).
mode_status
Implements ModeStatus (feature 0x8090).
mouse_pointer
Implements the MousePointer feature (ID 0x2200) that reports a mouse’s basic optical-sensor properties and pointer-tuning hints.
multi_platform
Implements MultiPlatform (feature 0x4531).
per_key_lighting
Implements the PerKeyLighting feature (ID 0x8081, version 0) that sets individual RGB zones (typically per-key) on a keyboard.
persistent_remappable_action
Implements the PersistentRemappableAction feature (ID 0x1c00) that persistently remaps a device control to a different HID action.
registry
Maintains a registry of well-known HID++2.0 features and their default implementations.
report_rate
Implements the legacy ReportRate feature (ID 0x8060).
reprog_controls
Implements SpecialKeysMseButtons / ReprogControlsV4 (feature 0x1b04).
rgb_effects
Implements the RgbEffects feature (ID 0x8071, version 4), the modern per-cluster RGB effect engine (successor to ColorLedEffects, 0x8070).
root
Implements the Root feature (ID 0x0000) that every device supports by default.
sidetone
Implements Sidetone (feature 0x8300) for audio devices.
smartshift
Implements the SmartShift feature (ID 0x2110) that allows controlling a smart shift enhanced scroll wheel.
smartshift_enhanced
Implements SmartShiftWheelEnhanced (feature 0x2111).
solar_dashboard
Implements the SolarKeyboardDashboard feature (ID 0x4301) for Logitech’s solar keyboards (e.g. the K750): scheduling light-measure reports, overriding the CheckLight LED, and receiving battery / light broadcast events.
thumbwheel
Implements the Thumbwheel feature (ID 0x2150) that allows configuration and diversion of thumbwheel events.
touch_mouse_raw
Implements the TouchMouseRaw feature (ID 0x6110) that exposes a touch mouse’s raw touch points: pad characteristics, the raw-data mode, and the raw-data / status events.
touchpad_raw_xy
Implements the TouchpadRawXy feature (ID 0x6100) that exposes a touchpad’s raw multi-touch data: pad characteristics, the raw-report mode, and a per-frame DualXyData event.
unified_battery
Implements the UnifiedBattery feature (ID 0x1004) that provides information about the battery status of the device.
vertical_scrolling
Implements VerticalScrolling (feature 0x2100).
wireless_device_status
Implements the WirelessDeviceStatus feature (ID 0x1d4b) that notifies the host about device reconnections.

Structs

FeatureType
A bitfield describing some properties of a feature.

Traits

CreatableFeature
Represents a Feature that can be instantiated automatically.
EmittingFeature
Represents a Feature that emits events of type T.
Feature
Represents a concrete implementation of a HID++2.0 device feature.