Specific device feature implementations.
Modules
- adjustable_
dpi - Implements the
AdjustableDpifeature (ID0x2201) that allows reading and changing a mouse sensor’s DPI. - backlight
- Implements the
Backlightfeature (ID0x1982, version 3) for keyboards with an adjustable backlight. - brightness_
control - Implements
BrightnessControl(feature0x8040). - change_
host - Implements the
ChangeHostfeature (ID0x1814) that selects which host / RF channel a multi-host device is connected to. - color_
led_ effects - Implements the
ColorLedEffectsfeature (ID0x8070, version 7), the per-zone RGB effect engine used by Logitech keyboards and mice. - crown
- Implements the
Crownfeature (ID0x4600) for the MX Master’s rotary crown: reading its capabilities, configuring its mode (HID vs diverted, free vs ratchet, timeouts), and receiving diverted rotation/touch/button events. - device_
friendly_ name - Implements the
DeviceFriendlyNamefeature (ID0x0007) that provides functionality to set and retrieve a custom device name. - device_
information - Implements the
DeviceInformationfeature (ID0x0003) that provides some general information about the device. - device_
type_ and_ name - Implements the
DeviceTypeAndNamefeature (ID0x0005) that provides some information about the marketing type and name of a device. - disable_
keys - Implements the
DisableKeysfeature (ID0x4521) that disables a fixed set of lock / system keys. - disable_
keys_ by_ usage - Implements the
DisableKeysByUsagefeature (ID0x4522) that disables or enables arbitrary keyboard keys by HID usage. - dual_
platform - Implements the
DualPlatformfeature (ID0x4530) that selects which of two OS platforms a device sends HID codes for. - equalizer
- Implements the
Equalizerfeature (ID0x8310, version 2) that configures an audio device’s equalizer (per-band gains) and microphone noise reduction. - extended_
dpi - Implements the
ExtendedAdjustableDpifeature (ID0x2202). - extended_
report_ rate - Implements
ExtendedAdjustableReportRate(feature0x8061). - feature_
set - Implements the
FeatureSetfeature (ID0x0001) that allows enumerating all the features supported by a device. - fn_
inversion - Implements function-key inversion features.
- hires_
wheel - Implements the
HiResWheelfeature (ID0x2121) that allows configuring and using high-resolution scrolling. - hosts_
info - Implements
HostsInfo(feature0x1815) for multi-host devices. - illumination
- Implements the
Illuminationfeature (ID0x1990) for devices with a controllable illumination light (brightness in Lumens and color temperature in Kelvin). - mode_
status - Implements
ModeStatus(feature0x8090). - mouse_
pointer - Implements the
MousePointerfeature (ID0x2200) that reports a mouse’s basic optical-sensor properties and pointer-tuning hints. - multi_
platform - Implements
MultiPlatform(feature0x4531). - per_
key_ lighting - Implements the
PerKeyLightingfeature (ID0x8081, version 0) that sets individual RGB zones (typically per-key) on a keyboard. - persistent_
remappable_ action - Implements the
PersistentRemappableActionfeature (ID0x1c00) that persistently remaps a device control to a different HID action. - registry
- Maintains a registry of well-known HID++2.0 features and their default implementations.
- report_
rate - Implements the legacy
ReportRatefeature (ID0x8060). - reprog_
controls - Implements
SpecialKeysMseButtons/ReprogControlsV4(feature0x1b04). - rgb_
effects - Implements the
RgbEffectsfeature (ID0x8071, version 4), the modern per-cluster RGB effect engine (successor toColorLedEffects,0x8070). - root
- Implements the
Rootfeature (ID0x0000) that every device supports by default. - sidetone
- Implements
Sidetone(feature0x8300) for audio devices. - smartshift
- Implements the
SmartShiftfeature (ID0x2110) that allows controlling a smart shift enhanced scroll wheel. - smartshift_
enhanced - Implements
SmartShiftWheelEnhanced(feature0x2111). - solar_
dashboard - Implements the
SolarKeyboardDashboardfeature (ID0x4301) for Logitech’s solar keyboards (e.g. the K750): scheduling light-measure reports, overriding the CheckLight LED, and receiving battery / light broadcast events. - thumbwheel
- Implements the
Thumbwheelfeature (ID0x2150) that allows configuration and diversion of thumbwheel events. - touch_
mouse_ raw - Implements the
TouchMouseRawfeature (ID0x6110) that exposes a touch mouse’s raw touch points: pad characteristics, the raw-data mode, and the raw-data / status events. - touchpad_
raw_ xy - Implements the
TouchpadRawXyfeature (ID0x6100) that exposes a touchpad’s raw multi-touch data: pad characteristics, the raw-report mode, and a per-frameDualXyDataevent. - unified_
battery - Implements the
UnifiedBatteryfeature (ID0x1004) that provides information about the battery status of the device. - vertical_
scrolling - Implements
VerticalScrolling(feature0x2100). - wireless_
device_ status - Implements the
WirelessDeviceStatusfeature (ID0x1d4b) that notifies the host about device reconnections.
Structs
- Feature
Type - A bitfield describing some properties of a feature.
Traits
- Creatable
Feature - Represents a
Featurethat can be instantiated automatically. - Emitting
Feature - Represents a
Featurethat emits events of typeT. - Feature
- Represents a concrete implementation of a HID++2.0 device feature.