pub struct DeviceFriendlyNameFeature { /* private fields */ }Expand description
Implements the DeviceFriendlyName / 0x0007 feature.
Implementations
Sourceimpl DeviceFriendlyNameFeature
impl DeviceFriendlyNameFeature
Sourcepub async fn get_friendly_name_length(
&self,
) -> Result<DeviceFriendlyNameLength, Hidpp20Error>
pub async fn get_friendly_name_length( &self, ) -> Result<DeviceFriendlyNameLength, Hidpp20Error>
Retrieves the length data of the friendly device name feature.
Sourcepub async fn get_friendly_name(
&self,
index: u8,
) -> Result<[u8; 15], Hidpp20Error>
pub async fn get_friendly_name( &self, index: u8, ) -> Result<[u8; 15], Hidpp20Error>
Retrieves a chunk of characters of the friendly name of the device, starting at a specific index (inclusive).
This function will always retrieve 15 bytes, filling up the rest with zeroes if the chunk is shorter than that.
Use this function in conjunction with Self::get_friendly_name_length
to retrieve the whole friendly name of the device.
A convenience wrapper implementing this functionality is provided as
Self::get_whole_friendly_name.
Sourcepub async fn get_whole_friendly_name(&self) -> Result<String, Hidpp20Error>
pub async fn get_whole_friendly_name(&self) -> Result<String, Hidpp20Error>
Retrieves the whole friendly name of the device by first calling
Self::get_friendly_name_length once and then repeatedly calling
Self::get_friendly_name until all characters were received.
Sourcepub async fn get_default_friendly_name(
&self,
index: u8,
) -> Result<[u8; 15], Hidpp20Error>
pub async fn get_default_friendly_name( &self, index: u8, ) -> Result<[u8; 15], Hidpp20Error>
Retrieves a chunk of characters of the default friendly name of the device, starting at a specific index (inclusive).
This function will always retrieve 15 bytes, filling up the rest with zeroes if the chunk is shorter than that.
Use this function in conjunction with Self::get_friendly_name_length
to retrieve the whole default friendly name of the device.
A convenience wrapper implementing this functionality is provided as
Self::get_whole_default_friendly_name.
Sourcepub async fn get_whole_default_friendly_name(
&self,
) -> Result<String, Hidpp20Error>
pub async fn get_whole_default_friendly_name( &self, ) -> Result<String, Hidpp20Error>
Retrieves the whole default friendly name of the device by first calling
Self::get_friendly_name_length once and then repeatedly calling
Self::get_default_friendly_name until all characters were received.
Sourcepub async fn set_friendly_name(
&self,
index: u8,
chunk: [u8; 15],
) -> Result<u8, Hidpp20Error>
pub async fn set_friendly_name( &self, index: u8, chunk: [u8; 15], ) -> Result<u8, Hidpp20Error>
Sets a chunk of the friendly device name, starting at a specific index (inclusive).
If the index and chunk combination would exceed the
DeviceFriendlyNameLength::name_max_length, the name is automatically
truncated by the device.
Returns the new total length of the friendly device name.
A convenience wrapper setting the whole friendly device name at once is
provided as Self::set_whole_device_name.
Sourcepub async fn set_whole_device_name(
&self,
name: String,
) -> Result<u8, Hidpp20Error>
pub async fn set_whole_device_name( &self, name: String, ) -> Result<u8, Hidpp20Error>
Sets the whole friendly device name, truncating the value to a maximum
of DeviceFriendlyNameLength::name_max_length bytes.
This method calls Self::get_friendly_name_length first to retrieve
the maximum length and then repeatedly calls Self::set_friendly_name
until the whole name is set.
Returns the total length of the name after setting it,
Sourcepub async fn reset_friendly_name(&self) -> Result<u8, Hidpp20Error>
pub async fn reset_friendly_name(&self) -> Result<u8, Hidpp20Error>
Resets the friendly device name to the default one.
Returns the total length of the name after resetting it,