DeviceEntityFirmwareInfo

Struct DeviceEntityFirmwareInfo 

#[non_exhaustive]
pub struct DeviceEntityFirmwareInfo { pub entity_type: DeviceEntityType, pub firmware_prefix: String, pub firmware_number: u8, pub revision: u8, pub build: u16, pub active: bool, pub transport_pid: u16, pub extra_version: [u8; 5], }
Represents information about the firmware of a specific device entity as obtained via DeviceInformationFeature::get_fw_info.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
entity_type: DeviceEntityType

The type of the described entity.

firmware_prefix: String

A 3-letter prefix for the firmware name.

firmware_number: u8

The firmware number.

This is represented in packed BCD format in the protocol itself, but decoding is handled by this implementation automatically.

revision: u8

The firmware revision.

This is represented in packed BCD format in the protocol itself, but decoding is handled by this implementation automatically.

build: u16

The firmware build.

This is represented in packed BCD format in the protocol itself, but decoding is handled by this implementation automatically.

active: bool

Whether the entity is the responding and active one.

Exactly one entity will be active at any given time.

transport_pid: u16

The transport protocol PID.

If this entity is the active one (see Self::active), this will be set to the actual PID. If it is not, this field COULD be all-zero.

extra_version: [u8; 5]

Optional extra versioning information.