DeviceInformation

Struct DeviceInformation 

#[non_exhaustive]
pub struct DeviceInformation { pub entity_count: u8, pub unit_id: [u8; 4], pub transport: DeviceTransport, pub model_id: [u16; 3], pub extended_model_id: u8, pub capabilities: DeviceInformationCapabilities, }
Represents information about the device as reported by DeviceInformationFeature::get_device_info.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
entity_count: u8

The amount of entities in the device from which version information can be retrieved using DeviceInformationFeature::get_fw_info.

unit_id: [u8; 4]

A 4-byte random value serving as a unique identifier (among all devices with the same Self::model_id) for the unit.

This field was added in feature version 1 and will always be 0 for older versions.

transport: DeviceTransport

A bitfield about which transport protocols the device supports.

This field was added in feature version 1 and will always be 0 for older versions.

model_id: [u16; 3]

A 6-byte array serving as the identifier for the device model.

This array will consist of the application PIDs of the different transport protocols supported by the device, as stated in Self::transport. The 16-bit PID for every supported transport protocol will be appended into this array, limiting the total amount of supported transport protocols to three.

This field was added in feature version 1 and will always be 0 for older versions.

extended_model_id: u8

An 8-bit value representing an additional configurable attribute for a given Self::model_id, set on the production line. This could be the color of the device.

This field was added in feature version 2 and will always be 0 for older versions.

capabilities: DeviceInformationCapabilities

Additional capability flags of this feature.

This field was added in feature version 4 together with the serial number retrieval function. All capabilities will be flagged as unsupported for older versions.