DeviceInformationFeature

Struct DeviceInformationFeature 

pub struct DeviceInformationFeature { /* private fields */ }
Implements the DeviceInformation / 0x0003 feature.

Implementations

Source

impl DeviceInformationFeature

pub async fn get_device_info(&self) -> Result<DeviceInformation, Hidpp20Error>

Retrieves general information about the device and its capabilities.

pub async fn get_fw_info( &self, entity_index: u8, ) -> Result<DeviceEntityFirmwareInfo, Hidpp20Error>

Retrieves information about the firmware of a specific entity, identified by its index bound by the value in DeviceInformation::entity_count.

pub async fn get_serial_number(&self) -> Result<String, Hidpp20Error>

Retrieves the serial number of the device.

This function was added in feature version 4 and will likely result in an v20::ErrorType::InvalidFunctionId error for older versions, so DeviceInformationCapabilities::serial_number should be verified before calling.