pub struct HiResWheelFeature { /* private fields */ }Expand description
Implements the HiResWheel / 0x2121 feature.
The analytics part of the feature is not implemented here as its data structure lacks any documentation.
Implementations
Sourceimpl HiResWheelFeature
impl HiResWheelFeature
Sourcepub async fn get_wheel_capabilities(
&self,
) -> Result<WheelCapabilities, Hidpp20Error>
pub async fn get_wheel_capabilities( &self, ) -> Result<WheelCapabilities, Hidpp20Error>
Retrieves the capabilities of the hi-res wheel and this feature.
Sourcepub async fn get_wheel_mode(&self) -> Result<WheelMode, Hidpp20Error>
pub async fn get_wheel_mode(&self) -> Result<WheelMode, Hidpp20Error>
Retrieves the current mode of the hi-res wheel.
Sourcepub async fn set_wheel_mode(
&self,
target: WheelEventTarget,
resolution: WheelResolution,
inverted: bool,
) -> Result<WheelMode, Hidpp20Error>
pub async fn set_wheel_mode( &self, target: WheelEventTarget, resolution: WheelResolution, inverted: bool, ) -> Result<WheelMode, Hidpp20Error>
Sets the mode of the hi-res wheel.
Setting the bit to control analytics collection is not supported in this
feature implementation as the analytics data structure is completely
undocumented.
If this is implemented in the future, a new implementation will do so to
not break this one.
Sourcepub async fn get_ratchet_switch_state(
&self,
) -> Result<WheelRatchetState, Hidpp20Error>
pub async fn get_ratchet_switch_state( &self, ) -> Result<WheelRatchetState, Hidpp20Error>
Retrieves the current state of the ratchet switch.