#[non_exhaustive]pub struct RatchetControlMode {
pub wheel_mode: WheelMode,
pub auto_disengage: u8,
pub auto_disengage_default: u8,
}Expand description
Represents the ratchet control mode of the mouse wheel.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.wheel_mode: WheelModeThe mode the wheel is currently set to.
This does not reflect the automatic disengage state.
auto_disengage: u8The amount of quarter-turns per second it takes for the wheel to automatically disengage.
If this value is 0xff, the wheel will not disengage automatically.
auto_disengage_default: u8The default value of Self::auto_disengage.