pub struct SmartShiftFeature { /* private fields */ }Expand description
Implements the SmartShift / 0x2110 feature.
Implementations
Sourceimpl SmartShiftFeature
impl SmartShiftFeature
Sourcepub async fn get_ratchet_control_mode(
&self,
) -> Result<RatchetControlMode, Hidpp20Error>
pub async fn get_ratchet_control_mode( &self, ) -> Result<RatchetControlMode, Hidpp20Error>
Retrieves the current ratchet control mode.
RatchetControlMode::wheel_mode will only reflect the value set
either by software or the wheel mode button. It will not provide
information about whether the wheel is in auto-disengaged mode.
Sourcepub async fn set_ratchet_control_mode(
&self,
wheel_mode: Option<WheelMode>,
auto_disengage: Option<u8>,
auto_disengage_default: Option<u8>,
) -> Result<(), Hidpp20Error>
pub async fn set_ratchet_control_mode( &self, wheel_mode: Option<WheelMode>, auto_disengage: Option<u8>, auto_disengage_default: Option<u8>, ) -> Result<(), Hidpp20Error>
Sets the ratchet control mode.
For auto_disengage (and auto_disengage_default respectively), the
values 0x01..=0xfe correspond to the amount of quarter-turns the wheel
has to make per second for the wheel to disengage.
0xff enables permanent ratchet mode.
All values are optional and will stay as they are if provided with
None.
For auto_disengage and auto_disengange_default, 0 will have the
same effect as None.