FeatureType

Struct FeatureType 

#[non_exhaustive]
pub struct FeatureType { pub obsolete: bool, pub hidden: bool, pub engineering: bool, pub manufacturing_deactivatable: bool, pub compliance_deactivatable: bool, }
A bitfield describing some properties of a feature.

Documentation is taken from https://drive.google.com/file/d/1ULmw9uJL8b8iwwUo5xjSS9F5Zvno-86y/view.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
obsolete: bool

An obsolete feature is a feature that has been replaced by a newer one, but is advertised in order for older SWs to still be able to support the feature (in case the old SW does not know yet the newer one).

hidden: bool

A SW hidden feature is a feature that should not be known/managed/used by end user configuration SW. The host should ignore this type of features.

engineering: bool

A hidden feature that has been disabled for user software. Used for internal testing and manufacturing.

manufacturing_deactivatable: bool

A manufacturing feature that can be permanently deactivated. It is usually also hidden and engineering.

This field was added in feature version 2 and will be false for all older versions.

compliance_deactivatable: bool

A compliance feature that can be permanently deactivated. It is usually also hidden and engineering.

This field was added in feature version 2 and will be false for all older versions.