pub async fn determine_version(
chan: &HidppChannel,
device_index: u8,
) -> Result<Option<ProtocolVersion>, ChannelError>Expand description
Tries to determine the protocol version of a specific device.
Returns Ok(None) if no device was found for the given device index.