#[non_exhaustive]pub enum Receiver {
Bolt(Receiver),
Unifying(Receiver),
}Expand description
Represents a HID++ wireless receiver.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl Receiver
impl Receiver
Sourcepub async fn get_unique_id(&self) -> Result<String, ReceiverError>
pub async fn get_unique_id(&self) -> Result<String, ReceiverError>
Provides a string that uniquely identifies the specific receiver.
This MAY be the serial number, but it may also be any other value that is defined as unique.